/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates a &lt;Option&gt; tag.
    The Option tag defaults to not having a closing &lt;/Option&gt;
    because it is optional in the spec. This can be
    overridden by setNeedClosingTag(true)

    @version $Id: Option.java,v 1.5 1999/04/22 01:35:06 stephan Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class Option extends MultiPartElement
{

    /**
        Private initialization routine.
    */
    {
        setElementType("option");
        setNeedClosingTag(false);
    }
    
    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
    */
    public Option()
    {
    }
    
    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
        
        @param value sets the attribute VALUE=""
    */
    public Option(String value)
    {
        setValue(value);
    }

    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
        
        @param label sets the attribute LABEL=""
        @param value sets the attribute VALUE=""
    */
    public Option(String label, String value)
    {
        setLabel(label);
        setValue(value);
    }

    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
        
        @param label sets the attribute LABEL=""
        @param value sets the attribute VALUE=""
    */
    public Option(String label, int value)
    {
        setLabel(label);
        setValue(value);
    }

    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
        
        @param label sets the attribute LABEL=""
        @param value sets the attribute VALUE=""
    */
    public Option(String label, double value)
    {
        setLabel(label);
        setValue(value);
    }

    /**
        Sets the LABEL="" attribute
        @param   label  the LABEL="" attribute
    */
    public Option setLabel(String label)
    {
        addAttribute("label",label);
        return this;
    }

    /**
        Sets the VALUE="" attribute
        @param   value  the VALUE="" attribute
    */
    public Option setValue(String value)
    {
        addAttribute("value",value);
        return this;
    }

    /**
        Sets the VALUE="" attribute
        @param   value  the VALUE="" attribute
    */
    public Option setValue(int value)
    {
        addAttribute("value",Integer.toString(value));
        return this;
    }

    /**
        Sets the VALUE="" attribute
        @param   value  the VALUE="" attribute
    */
    public Option setValue(double value)
    {
        addAttribute("value",Double.toString(value));
        return this;
    }

    /**
        Sets the selected value
        @param   selected  true or false
    */
    public Option setSelected(boolean selected)
    {
        if ( selected == true )
            addAttribute("selected", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("selected");
            
        return(this);
    }

    /**
        Sets the disabled value
        @param   disabled  true or false
    */
    public Option setDisabled(boolean disabled)
    {
        if ( disabled == true )
            addAttribute("disabled", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("disabled");
            
        return(this);
    }
    
    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public Option addElement(Element element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }
    
    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public Option addElement(String element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }

    /**
        Creates a group of options.
        @param  Creates a group of options.
     */
    public Option[] addElement(String[] element)
    {
        Option[] option = new Option[element.length];
        for(int x = 0; x < element.length; x++)
        {
            option[x]= new Option().addElement(element[x]);
        }
        return(option);
    }
}
